##  View the Roadmap
With all initiatives for the rationalization prepared, you can now visualize your roadmap with the Initiative Roadmap report. It shows initiatives and their lifecycle stage. To focus on the initiatives for the rationalization, use the filters and drill down options.
The initiative roadmap report helps you identify next steps. For example, you could improve the data quality and completeness. This means looking for typical data gaps, such as applications classified for elimination missing an end of life date.
Configure the report:
  * For Drilldown to select Applications
  * In the Advanced Settings activate Show dependencies
  * Optional: Set Subscription role to Responsible
  * Optional: For Field select Business Value or Project Risk


![Application rationalization project roadmap with timelines for elimination, migration, and investment phases](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio32283082bc1e4778916de86db3dc3845_HiRes.png)
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
